==> aspose_words_cloud-20.6.0-py3-none-any.whl: asposewordscloud/models/bookmarks.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="bookmarks.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class Bookmarks(object):
    """Represents an array of bookmarks.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bookmark_list': 'list[Bookmark]'
    }

    attribute_map = {
        'link': 'Link',
        'bookmark_list': 'BookmarkList'
    }

    def __init__(self, link=None, bookmark_list=None):  # noqa: E501
        """Bookmarks - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bookmark_list = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bookmark_list is not None:
            self.bookmark_list = bookmark_list

    @property
    def link(self):
        """Gets the link of this Bookmarks.  # noqa: E501

        Gets or sets link to the document.  # noqa: E501

        :return: The link of this Bookmarks.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Bookmarks.

        Gets or sets link to the document.  # noqa: E501

        :param link: The link of this Bookmarks.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bookmark_list(self):
        """Gets the bookmark_list of this Bookmarks.  # noqa: E501

        Gets or sets array of bookmarks.  # noqa: E501

        :return: The bookmark_list of this Bookmarks.  # noqa: E501
        :rtype: list[Bookmark]
        """
        return self._bookmark_list

    @bookmark_list.setter
    def bookmark_list(self, bookmark_list):
        """Sets the bookmark_list of this Bookmarks.

        Gets or sets array of bookmarks.  # noqa: E501

        :param bookmark_list: The bookmark_list of this Bookmarks.  # noqa: E501
        :type: list[Bookmark]
        """
        self._bookmark_list = bookmark_list


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Bookmarks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> aspose_words_cloud-21.2.0-py3-none-any.whl: asposewordscloud/models/bookmarks.py <==
# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="bookmarks.py">
#   Copyright (c) 2021 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import datetime
import six
import json


class Bookmarks(object):
    """Represents an array of bookmarks.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bookmark_list': 'list[Bookmark]'
    }

    attribute_map = {
        'link': 'Link',
        'bookmark_list': 'BookmarkList'
    }

    def __init__(self, link=None, bookmark_list=None):  # noqa: E501
        """Bookmarks - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bookmark_list = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bookmark_list is not None:
            self.bookmark_list = bookmark_list

    @property
    def link(self):
        """Gets the link of this Bookmarks.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this Bookmarks.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Bookmarks.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this Bookmarks.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bookmark_list(self):
        """Gets the bookmark_list of this Bookmarks.  # noqa: E501

        Gets or sets the array of bookmarks.  # noqa: E501

        :return: The bookmark_list of this Bookmarks.  # noqa: E501
        :rtype: list[Bookmark]
        """
        return self._bookmark_list

    @bookmark_list.setter
    def bookmark_list(self, bookmark_list):
        """Sets the bookmark_list of this Bookmarks.

        Gets or sets the array of bookmarks.  # noqa: E501

        :param bookmark_list: The bookmark_list of this Bookmarks.  # noqa: E501
        :type: list[Bookmark]
        """
        self._bookmark_list = bookmark_list


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Bookmarks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
